@@ -1,6 +1,7 @@
 """Syntax checks"""
 
 import os
+import shutil
 
 import pytest
 
@@ -77,7 +78,11 @@ def test_yamllint(pytestconfig, runner, yamllint_version):
 
 def test_man(runner):
     """Check for warnings from man"""
-    run = runner(command=["man.REAL", "--warnings", "./yadm.1"])
+    if shutil.which("mandoc"):
+        command = ["mandoc", "-T", "lint"]
+    else:
+        command = ["groff", "-ww", "-z"]
+    run = runner(command=command + ["-man", "./yadm.1"])
     assert run.success
+    assert run.out == ""
     assert run.err == ""
-    assert "yadm - Yet Another Dotfiles Manager" in run.out
