@@ -8,14 +8,14 @@ def test_bootstrap_missing(runner, paths):
 
 def test_bootstrap_no_exec(runner, paths):
     """Test result of bootstrap_available, when bootstrap not executable"""
-    paths.bootstrap.write('')
+    paths.bootstrap.write("")
     paths.bootstrap.chmod(0o644)
     run_test(runner, paths, False)
 
 
 def test_bootstrap_exec(runner, paths):
     """Test result of bootstrap_available, when bootstrap executable"""
-    paths.bootstrap.write('')
+    paths.bootstrap.write("")
     paths.bootstrap.chmod(0o775)
     run_test(runner, paths, True)
 
@@ -27,7 +27,7 @@ def run_test(runner, paths, success):
         YADM_BOOTSTRAP='{paths.bootstrap}'
         bootstrap_available
     """
-    run = runner(command=['bash'], inp=script)
+    run = runner(command=["bash"], inp=script)
     assert run.success == success
-    assert run.err == ''
-    assert run.out == ''
+    assert run.err == ""
+    assert run.out == ""
