@@ -1,4 +1,5 @@
 """Unit tests: relative_path"""
+
 import pytest
 
 
@@ -10,11 +11,16 @@ import pytest
         ("/A/B/C", "/A/B/C", ""),
         ("/A/B/C", "/A/B/C/D", "D"),
         ("/A/B/C", "/A/B/C/D/E", "D/E"),
+        ("/A/B/C", "/A/B/CD", "../CD"),
+        ("/A/B/C", "/A/BB/C", "../../BB/C"),
         ("/A/B/C", "/A/B/D", "../D"),
         ("/A/B/C", "/A/B/D/E", "../D/E"),
         ("/A/B/C", "/A/D", "../../D"),
         ("/A/B/C", "/A/D/E", "../../D/E"),
         ("/A/B/C", "/D/E/F", "../../../D/E/F"),
+        ("/", "/A/B/C", "A/B/C"),
+        ("/A/B/C", "/", "../../.."),
+        ("/A/B B/C", "/A/C C/D", "../../C C/D"),
     ],
 )
 def test_relative_path(runner, paths, base, full_path, expected):
