@@ -35,13 +35,13 @@ wrong class 1
 {{% if yadm.class != "wronglcass" %}}
 Included section from !=
 {{%     endif\t\t  %}}
-{{% if yadm.class == "{LOCAL_CLASS}" %}}
+{{% if yadm.class == "{LOCAL_CLASS.lower()}" %}}
 Included section for class = {{{{yadm.class}}}} ({{{{yadm.class}}}} repeated)
 Multiple lines
 {{% else %}}
 Should not be included...
 {{% endif %}}
-{{% if yadm.class == "{LOCAL_CLASS2}" %}}
+{{% if yadm.class == "{LOCAL_CLASS2.upper()}" %}}
 Included section for second class
 {{% endif %}}
 {{% if yadm.class == "wrongclass2" %}}
@@ -50,7 +50,7 @@ wrong class 2
 {{% if yadm.arch == "wrongarch1" %}}
 wrong arch 1
 {{% endif %}}
-{{% if yadm.arch == "{LOCAL_ARCH}" %}}
+{{% if yadm.arch == "{LOCAL_ARCH.title()}" %}}
 Included section for arch = {{{{yadm.arch}}}} ({{{{yadm.arch}}}} repeated)
 {{% endif %}}
 {{% if yadm.arch == "wrongarch2" %}}
@@ -59,7 +59,7 @@ wrong arch 2
 {{% if yadm.os == "wrongos1" %}}
 wrong os 1
 {{% endif %}}
-{{% if yadm.os == "{LOCAL_SYSTEM}" %}}
+{{% if yadm.os == "{LOCAL_SYSTEM.lower()}" %}}
 Included section for os = {{{{yadm.os}}}} ({{{{yadm.os}}}} repeated)
 {{% endif %}}
 {{% if yadm.os == "wrongos2" %}}
@@ -68,7 +68,7 @@ wrong os 2
 {{% if yadm.hostname == "wronghost1" %}}
 wrong host 1
 {{% endif %}}
-{{% if yadm.hostname == "{LOCAL_HOST}" %}}
+{{% if yadm.hostname == "{LOCAL_HOST.upper()}" %}}
 Included section for host = {{{{yadm.hostname}}}} ({{{{yadm.hostname}}}} again)
 {{% endif %}}
 {{% if yadm.hostname == "wronghost2" %}}
@@ -77,7 +77,7 @@ wrong host 2
 {{% if yadm.user == "wronguser1" %}}
 wrong user 1
 {{% endif %}}
-{{% if yadm.user == "{LOCAL_USER}" %}}
+{{% if yadm.user == "{LOCAL_USER.title()}" %}}
 Included section for user = {{{{yadm.user}}}} ({{{{yadm.user}}}} repeated)
 {{% endif %}}
 {{% if yadm.user == "wronguser2" %}}
@@ -86,7 +86,7 @@ wrong user 2
 {{% if yadm.distro == "wrongdistro1" %}}
 wrong distro 1
 {{% endif %}}
-{{% if yadm.distro == "{LOCAL_DISTRO}" %}}
+{{% if yadm.distro == "{LOCAL_DISTRO.lower()}" %}}
 Included section for distro = {{{{yadm.distro}}}} ({{{{yadm.distro}}}} again)
 {{% endif %}}
 {{% if yadm.distro == "wrongdistro2" %}}
@@ -95,14 +95,14 @@ wrong distro 2
 {{% if yadm.distro_family == "wrongfamily1" %}}
 wrong family 1
 {{% endif %}}
-{{% if yadm.distro_family == "{LOCAL_DISTRO_FAMILY}" %}}
+{{% if yadm.distro_family == "{LOCAL_DISTRO_FAMILY.upper()}" %}}
 Included section for distro_family = \
 {{{{yadm.distro_family}}}} ({{{{yadm.distro_family}}}} again)
 {{% endif %}}
 {{% if yadm.distro_family == "wrongfamily2" %}}
 wrong family 2
 {{% endif %}}
-{{% if env.VAR == "{ENV_VAR}" %}}
+{{% if env.VAR == "{ENV_VAR.title()}" %}}
 Included section for env.VAR = {{{{env.VAR}}}} ({{{{env.VAR}}}} again)
 {{% endif %}}
 {{% if env.VAR == "wrongenvvar" %}}
@@ -141,7 +141,7 @@ end of template
 
 INCLUDE_BASIC = "basic\n"
 INCLUDE_VARIABLES = """\
-included <{{ yadm.class }}> file
+included <{{ yadm.class }}> file ({{yadm.filename}})
 
 empty line above
 """
@@ -151,8 +151,8 @@ TEMPLATE_INCLUDE = """\
 The first line
 {% include empty %}
 An empty file removes the line above
-{%include basic%}
-{% include "./variables.{{ yadm.os }}"  %}
+{%include ./basic%}
+{% include "variables.{{ yadm.os }}"  %}
   {% include dir/nested %}
 Include basic again:
 {% include basic %}
@@ -161,7 +161,7 @@ EXPECTED_INCLUDE = f"""\
 The first line
 An empty file removes the line above
 basic
-included <{LOCAL_CLASS}> file
+included <{LOCAL_CLASS}> file (VARIABLES_FILENAME)
 
 empty line above
 no newline at the end
@@ -231,7 +231,7 @@ def test_template_default(runner, yadm, tmpdir):
         local_user="{LOCAL_USER}"
         local_distro="{LOCAL_DISTRO}"
         local_distro_family="{LOCAL_DISTRO_FAMILY}"
-        template_default "{input_file}" "{output_file}"
+        template default "{input_file}" "{output_file}"
     """
     run = runner(command=["bash"], inp=script, env={"VAR": ENV_VAR})
     assert run.success
@@ -251,7 +251,7 @@ def test_source(runner, yadm, tmpdir):
     script = f"""
         YADM_TEST=1 source {yadm}
         set_awk
-        template_default "{input_file}" "{output_file}"
+        template default "{input_file}" "{output_file}"
     """
     run = runner(command=["bash"], inp=script)
     assert run.success
@@ -280,17 +280,19 @@ def test_include(runner, yadm, tmpdir):
     input_file.chmod(FILE_MODE)
     output_file = tmpdir.join("output")
 
+    expected = EXPECTED_INCLUDE.replace("VARIABLES_FILENAME", str(variables_file))
+
     script = f"""
         YADM_TEST=1 source {yadm}
         set_awk
         local_class="{LOCAL_CLASS}"
         local_system="{LOCAL_SYSTEM}"
-        template_default "{input_file}" "{output_file}"
+        template default "{input_file}" "{output_file}"
     """
     run = runner(command=["bash"], inp=script)
     assert run.success
     assert run.err == ""
-    assert output_file.read() == EXPECTED_INCLUDE
+    assert output_file.read() == expected
     assert os.stat(output_file).st_mode == os.stat(input_file).st_mode
 
 
@@ -305,7 +307,7 @@ def test_nested_ifs(runner, yadm, tmpdir):
         YADM_TEST=1 source {yadm}
         set_awk
         local_user="me"
-        template_default "{input_file}" "{output_file}"
+        template default "{input_file}" "{output_file}"
     """
     run = runner(command=["bash"], inp=script)
     assert run.success
@@ -323,7 +325,7 @@ def test_env(runner, yadm, tmpdir):
     script = f"""
         YADM_TEST=1 source {yadm}
         set_awk
-        template_default "{input_file}" "{output_file}"
+        template default "{input_file}" "{output_file}"
     """
     run = runner(command=["bash"], inp=script)
     assert run.success
