@@ -1,28 +1,30 @@
 """Unit tests: yadm.[git,gpg]-program"""
 
 import os
+
 import pytest
 
 
 @pytest.mark.parametrize(
-    'executable, success, value, match', [
-        (None, True, 'program', None),
-        ('cat', True, 'cat', None),
-        ('badprogram', False, None, 'badprogram'),
-    ], ids=[
-        'executable missing',
-        'valid alternative',
-        'invalid alternative',
-    ])
-@pytest.mark.parametrize('program', ['git', 'gpg'])
-def test_x_program(
-        runner, yadm_cmd, paths, program, executable, success, value, match):
+    "executable, success, value, match",
+    [
+        (None, True, "program", None),
+        ("cat", True, "cat", None),
+        ("badprogram", False, None, "badprogram"),
+    ],
+    ids=[
+        "executable missing",
+        "valid alternative",
+        "invalid alternative",
+    ],
+)
+@pytest.mark.parametrize("program", ["git", "gpg"])
+def test_x_program(runner, yadm_cmd, paths, program, executable, success, value, match):
     """Set yadm.X-program, and test result of require_X"""
 
     # set configuration
     if executable:
-        os.system(' '.join(yadm_cmd(
-            'config', f'yadm.{program}-program', executable)))
+        os.system(" ".join(yadm_cmd("config", f"yadm.{program}-program", executable)))
 
     # test require_[git,gpg]
     script = f"""
@@ -32,11 +34,11 @@ def test_x_program(
         require_{program}
         echo ${program.upper()}_PROGRAM
     """
-    run = runner(command=['bash'], inp=script)
+    run = runner(command=["bash"], inp=script)
     assert run.success == success
 
     # [GIT,GPG]_PROGRAM set correctly
-    if value == 'program':
+    if value == "program":
         assert run.out.rstrip() == program
     elif value:
         assert run.out.rstrip() == value
@@ -45,4 +47,4 @@ def test_x_program(
     if match:
         assert match in run.err
     else:
-        assert run.err == ''
+        assert run.err == ""
